@@ -39,20 +39,22 @@ def python_get_version_from_setup():
 def python_get_version_from_init():
     logger.info("get version from package __init__.py file")
     init_path_pattern =  os.path.join(os.environ.get('GITHUB_WORKSPACE'), "*", "__init__.py")
-    init_path = glob.glob(init_path_pattern)[0]
-    try:
+    found_init = glob.glob(init_path_pattern)
+    if len(found_init):
+        init_path = found_init[0]
         with open(init_path) as fi:
             result = re.search(r'__version__\s*=\s*[\'"]([^\'"]*)[\'"]', fi.read())
             if result:
                 version = result.group(1)
-                logger.info("version {version}")
+                logger.info(f"version {version}")
                 return version
             else:
                 return None
-    except FileNotFoundError:
+    else:
         return None
 
 def python_get_version_from_version_txt():
+    logger.info("get version from version.text file")
     version_text_filename = 'version.txt'
     try:
         versiontext_file = next(Path('src').rglob(version_text_filename))
